@@ -24,12 +24,26 @@ setMethod("show", "Pca", function(object) myPcaPrint(object))
 setMethod("summary", "Pca", function(object, ...){
     vars <- getEigenvalues(object)
     vars <- vars/sum(vars)
-    importance <- rbind("Standard deviation" = getSdev(object),
-                        "Proportion of Variance" = round(vars,5),
-                        "Cumulative Proportion" = round(cumsum(vars), 5))
+
+    ## If k < p, use the stored initial eigenvalues and total explained variance, if any
+    if(length(vars) < object@rank)
+    {
+        if(length(object@eig0) > 0 && length(object@totvar0) > 0)
+        {
+            vars <- object$eig0/object$totvar0
+            vars <- vars[1:object$k]
+        } else
+            vars <- NULL
+    }
+    importance <- if(is.null(vars)) rbind("Standard deviation" = getSdev(object))
+                  else              rbind("Standard deviation" = getSdev(object),
+                                         "Proportion of Variance" = round(vars,5),
+                                         "Cumulative Proportion" = round(cumsum(vars), 5))
+
     colnames(importance) <- colnames(getLoadings(object))
     new("SummaryPca", pcaobj=object, importance=importance)
 })
+
 setMethod("show", "SummaryPca", function(object){
 
     cat("\nCall:\n")
@@ -39,6 +53,12 @@ setMethod("show", "SummaryPca", function(object){
 
     cat("Importance of components:\n")
     print(object@importance, digits = digits)
+
+    if(nrow(object@importance) == 1)
+        cat("\nNOTE: Proportion of Variance and Cumulative Proportion are not shown",
+            "\nbecause the chosen number of components k =", object@pcaobj@k,
+            "\nis smaller than the rank of the data matrix =", object@pcaobj@rank, "\n")
+
     invisible(object)
 })
 
@@ -48,7 +68,7 @@ setMethod("predict",   "Pca", function(object, ...){
     predict(getPrcomp(object), ...)
 })
 setMethod("screeplot", "Pca", function(x, ...){
-    screeplot(getPrcomp(x), ...)
+    pca.screeplot(x, ...)
 })
 
 setMethod("biplot",    "Pca", function(x, choices=1L:2L, scale=1, ...){
@@ -394,6 +414,29 @@ kernelEVD <- function(x, scale=FALSE, signflip=TRUE){
     }
 }
 
+pca.screeplot <- function (obj, k, type = c("barplot", "lines"), main = deparse1(substitute(obj)), ...)
+{
+    type <- match.arg(type)
+    pcs <- if(is.null(obj@eig0) || length(obj@eig0) == 0) obj@eigenvalues else obj@eig0
+    k <- if(missing(k)) min(10, length(pcs))
+         else           min(k, length(pcs))
+
+    xp <- seq_len(k)
+
+    dev.hold()
+    on.exit(dev.flush())
+    if (type == "barplot")
+        barplot(pcs[xp], names.arg = names(pcs[xp]), main = main,
+            ylab = "Variances", ...)
+    else {
+        plot(xp, pcs[xp], type = "b", axes = FALSE, main = main,
+            xlab = "", ylab = "Variances", ...)
+        axis(2)
+        axis(1, at = xp, labels = names(pcs[xp]))
+    }
+    invisible()
+}
+
 ## Score plot of the Pca object 'obj' - scatterplot of ith against jth score
 ##  with superimposed tollerance (0.975) ellipse
 pca.scoreplot <- function(obj, i=1, j=2, main, id.n=0, ...)
